@@ -26,27 +26,22 @@
 #' \dontrun{
 #' library(googleAuthR)
 #' ## change the native googleAuthR scopes to the one needed.
-#' options("googleAuthR.scopes.selected" =
-#'   c("https://www.googleapis.com/auth/urlshortener"))
+#' options("googleAuthR.scopes.selected" = "email")
 #'
-#' shorten_url <- function(url){
-#'
-#'   body = list(
-#'     longUrl = url
-#'     )
-#'
-#'   f <- gar_api_generator("https://www.googleapis.com/urlshortener/v1/url",
-#'                       "POST",
-#'                       data_parse_function = function(x) x$id)
-#'
-#'    f(the_body = body)
-#'  }
+#' get_email <- function(){
+#'    f <- gar_api_generator("https://openidconnect.googleapis.com/v1/userinfo",
+#'                           "POST",
+#'                           data_parse_function = function(x) x$email,
+#'                           checkTrailingSlash = FALSE)
+#'                           
+#'    f()
+#'    }
 #'
 #' To use the above functions:
 #' library(googleAuthR)
 #' # go through authentication flow
 #' gar_auth()
-#' s <- shorten_url("http://markedmondson.me")
+#' s <- get_email()
 #' s
 #' }
 #'
@@ -207,8 +202,7 @@ gar_api_generator <- function(baseURI,
                                              data_parse_func = data_parse_function,
                                              content = req$content),
                              authentication = list(
-                               token = Authentication$public_fields$token,
-                               method = Authentication$public_fields$method
+                               token = .auth$cred
                              )),
                              class = "gar_parse_error")
         
